<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="Content-Type" content="text/html" charset="UTF-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" />
    <title>{{title}}</title>
    <meta name="HandheldFriendly" content="True" />
    <meta name="MobileOptimized" content="320" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link rel="stylesheet" type="text/css" href="{{asset 'css/normalize.css'}}" />
    <link rel="stylesheet" type="text/css" href="{{asset 'css/nprogress.css'}}" />
    <link rel="stylesheet" type="text/css" href="{{asset 'css/style.css'}}" />
    <link rel="stylesheet" type="text/css" href="{{asset 'css/pilcrow.css'}}" />
    <link rel="stylesheet" type="text/css" href="http://fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,600italic,700italic,400,600,700,300" />
  </head>

  <body class="home-template">
    <div id="wrapper">
      <div id="ajax-container">
        <div id="latest-post" class="container">
          <article class="post">
            <header class="post-header">
            <!--
               <h1 class="post-title">Introducing Ghostwriter</h1>

              <p class="post-date">
                <time datetime="Thu Sep 19 2013 11:58:31 GMT+0000 (UTC)">Published September 19th 2013</time>
              </p>
            -->
            </header>
          {{~> content}}

          </article>
        </div>
      </div>
    </div>
    <footer class="footer">
      <div class="container">
        <div class="site-title-wrapper">
        </div>
        <p class="footer-copyright">Guichet Entreprises
        </p>
      </div>
    </footer>
  </body>

</html>
