<!DOCTYPE html>
<html>

<head>
  <title>{{title}}</title>
  <meta name="author"
        content="{{author}}" />
  <meta name="description"
        content="{{description}}" />
  <meta name="keywords"
        content="{{keywords}}" />
  <meta http-equiv="Content-Type"
        content="text/html; charset=UTF-8">
  <meta name="viewport"
        content="width=device-width, initial-scale=1.0" />
  <link type="text/css"
        rel="stylesheet"
        href="{{asset 'style.css'}}" />
  <link type="text/css"
        rel="stylesheet"
        href="{{asset 'pilcrow.css'}}" />
  <link type="text/css"
        rel="stylesheet"
        href="{{asset 'hljs-github.min.css'}}" />
</head>

<body>
  {{~> content}}
</body>

</html>