<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <title>{{title}}</title>
    <link type="text/css" rel="stylesheet" href="{{asset 'css/bootstrap.css'}}"/>
    <link type="text/css" rel="stylesheet" href="{{asset 'css/bootstrap-responsive.css'}}"/>
    <link type="text/css" rel="stylesheet" href="{{asset 'css/pilcrow.css'}}"/>
    <link type="text/css" rel="stylesheet" href="{{asset 'css/hljs-github.min.css'}}"/>
    <link type="text/css" rel="stylesheet" href="{{asset 'css/style.css'}}"/>
    <style>
    body {
      background: url('{{asset "img/textured_paper.png"}}') repeat top left;
      background-color: #f6f6f6;
    }
    </style>
  </head>
<body>

  <div class="container-fluid">
    <div class="row-fluid">
      <div class="span3">
        {{~> toc }}
      </div>
      <div class="span9 main">
        {{~> content}}
      </div>
    </div>
  </div>

  <script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js"></script>
  <script type="text/javascript" src="{{asset 'js/bootstrap.min.js'}}"></script>
</body>
</html>
