<!DOCTYPE html>
<html>
  <head>
    <title>{{title}}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <link type="text/css" rel="stylesheet" href="{{asset 'style.css'}}" />
    <link type="text/css" rel="stylesheet" href="{{asset 'pilcrow.css'}}" />
    <link type="text/css" rel="stylesheet" href="{{asset 'hljs-solarized-light.min.css'}}"/>
  </head>
<body>
{{~> content}}
</body>
</html>
