<!DOCTYPE html>
<html>
  <head>
    <title>{{title}}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <link rel="stylesheet" href="{{asset 'css/style.css'}}" />
    <link rel="stylesheet" href="{{asset 'css/pilcrow.css'}}" />
    <link type="text/css" rel="stylesheet" href="{{asset 'css/hljs-github.min.css'}}"/>
  </head>
<body>

  <div id="toc">
    <div id="toc-inner">
      {{~> toc}}
    </div>
  </div>

  <div id="wrapper">
    <div id="header">

    </div>

    <div class="clear"></div>
    <div id="main">
      <div id="content" class="post">
      {{~> content}}
      </div>
    </div>

    <div class="clear">
    </div>

    <div id="footer">
    </div>
  </div>
</body>
</html>
