<!DOCTYPE html>
<html>
  <head>
    <title>{{title}}</title>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <link href='http://fonts.googleapis.com/css?family=Andika|Droid+Sans+Mono|Cantarell:400,700,400italic' rel='stylesheet' type='text/css' />
    <script src="{{asset 'jquery-1.6.1.min.js'}}"></script>
    <link type="text/css" rel="stylesheet" href="{{asset 'style.css'}}"/>
    <link type="text/css" rel="stylesheet" href="{{asset 'assert.css'}}"/>
    <link type="text/css" rel="stylesheet" href="{{asset 'prettify.css'}}"/>
    <link type="text/css" rel="stylesheet" href="{{asset 'pilcrow.css'}}"/>
    <link type="text/css" rel="stylesheet" href="{{asset 'hljs-github.min.css'}}"/>

    <script type="text/javascript" src="{{asset 'prettify.js'}}"></script>
    <!-- Script runner -->
    <script type="text/javascript" src="{{asset 'runner.js'}}"></script>
  </head>
<body>
  <div id="wrapper">
    <div id="header">
    </div>
    <div class="clear">
      <hr>
    </div>

    <div id="main">
      <div id="container">
        <div id="content" class="post">
         {{~> content}}

         <div id="bottom_navi">
          <a href="{{prev}}.html"> &lt; &lt; Previous Chapter</a> | <a href="{{next}}.html">Next Chapter &gt; &gt;</a>
         </div>
        </div>
      </div>
    </div>
    <div id="sidebar">
      {{~> toc}}
    </div>
    <div class="clear">
    </div>

    <div id="footer">
      <p>CSS by <a href="http://mixu.net/">Mikito Takada</a>.</p>
    </div>
  </div>
</body>
</html>
