.post h1,
.post h2,
.post h3,
.post h4,
.post h5,
.post h6 {
  position: relative;
}

.post h1:hover .header-link:before,
.post h2:hover .header-link:before,
.post h3:hover .header-link:before,
.post h4:hover .header-link:before,
.post h5:hover .header-link:before,
.post h6:hover .header-link:before {
    content: "\00B6";/* pilcrow */
    color: #888;
    font-size: smaller;
}

.post .header-link {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;

  position: absolute;
  top: 0;
  left: -0.7em;
  display: block;
  padding-right: 1em;
}

.post h1:hover .header-link,
.post h2:hover .header-link,
.post h3:hover .header-link,
.post h4:hover .header-link,
.post h5:hover .header-link,
.post h6:hover .header-link {
  display: inline-block;
  text-decoration: none;
}
