/*********************************************************************
This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any
means.

For more information, please refer to <http://unlicense.org/>
*********************************************************************/

/*
WiTeX
https://github.com/AndrewBelt/WiTeX
*/


/* Latin Modern (LaTeX default) font */

@font-face {
	font-family: 'Latin Modern Roman';
	font-weight: normal;
	font-style: normal;
	src: url('../fonts/lmroman10-regular.woff') format('woff');
}

@font-face {
	font-family: 'Latin Modern Roman';
	font-weight: bold;
	font-style: normal;
	src: url('../fonts/lmroman10-bold.woff') format('woff');
}

@font-face {
	font-family: 'Latin Modern Roman';
	font-weight: normal;
	font-style: italic;
	src: url('../fonts/lmroman10-italic.woff') format('woff');
}

@font-face {
	font-family: 'Latin Modern Roman';
	font-weight: bold;
	font-style: italic;
	src: url('../fonts/lmroman10-bolditalic.woff') format('woff');
}

/* Page Layout */

body {
  background-color: white;
  font-size: 13pt;
}

body {
	font-family: 'Latin Modern Roman', serif;
}

h1, h2, h3, h4, h5, h6 {
	border: none;
	font-weight: bold;
}

a, a:visited {
	color: #a00;
}

ul {
	list-style: disc;
}

/* Content Box */

.content {
	max-width: 720px;
	margin: 2em auto;
}

.content > h1:first-child {
	text-align: center;
	display: block;
}

/* Article Body */

.content {
	text-align: justify;
	-moz-hyphens: auto;
	-webkit-hyphens: auto;
	hyphens: auto;
  padding: 0 1em;
}

dl dd {
	/* center definitions (most useful for display equations) */
	text-align: center;
}

@media (min-width: 43.75em) {
  .content {
    padding: 0;
  }
}
