/* Minimal font */
body, div, dl, dt, dd, ul, ol, li, h1, h2, h3, h4, h5, h6, pre,
form, fieldset, input, p, blockquote, table, th, td, embed, object, hr {
  padding: 0;
  margin: 0;
  }
table {
  border-collapse: collapse;
  border-spacing: 0;
  }
fieldset, img, abbr {
  border: 0;
  }
address, caption, cite, code, dfn, em,
h1, h2, h3, h4, h5, h6, th, var {
  font-weight: normal;
  font-style: normal;
  }
ul {
  list-style: none;
  }
caption, th {
  text-align: left;
  }
h1, h2, h3, h4, h5, h6 {
  font-size: 1.0em;
  }
q:before, q:after {
  content: '';
  }
a, ins {
  text-decoration: none;
  }

body {
  font-family: Helvetica, Arial, 'Liberation Sans', FreeSans, sans-serif;
  background-color: white;
}

a {
  color: #c00;
}

hr {
  color: #ededed;
  background-color: #ededed;
  height: 1px;
  border: none;
}

/* Header */
#header {
  margin-top: 2.029em;
  margin-left: auto;
  margin-right: auto;
  width: 940px;

  position: relative;
  height: 4em;
}

#header h1 {
  font-family: 'Andika', sans-serif;
  font-size: 37px;
  font-weight: normal;
  line-height: 48px;
}
#header span {
  font-size: 14px;
}

#brand {
  position: absolute; bottom: 0; left: 0;
}

#navi {
  position: absolute;
  right:0;
  bottom:0;
}

#navi li {
  display: inline;
  list-style-type: none;
  padding-right: 20px;
}

div.clear {
  clear: both;
}

div.clear hr {
  margin: 18px 0px;
}

#wrapper {
  margin-left: auto;
  margin-right: auto;
  width: 95%;
}

#container {
  margin-right: 5px;
  margin-left: 15px;
  overflow: visible;
}

/* Content */
#content {
  font-size: 16px;
  line-height: 26px;

  margin-bottom: 0;
  padding-bottom: 20px;
  overflow: visible;
}

/* Post titles */

.post h1 {
  font-size: 36px;
  line-height: 1;
  margin-bottom: 0.5em;
}

.post h2 {
  font-size: 24px;
  text-align: left;
  color: black;
  line-height: 32px;
  margin-bottom: 15px;
}

.post p {
  margin: 0 0 1.5em;
}

.post p,
.post ul,
.post ol {
  max-width: 36em;
}

.post ul {
  list-style-type: disc;
}

.post ul, .post ol {
  margin: 0 1.5em 1.5em 0;
  padding-left: 3.333em;
}

.post pre ul, .post pre ol {
  margin: 0;
  padding: 0;
}

.post pre {
  font-size: 14px;

  padding: 2em 1.6em 2em 1.2em;
  vertical-align: top;
  background: #F8F8F8;
  border: 1px solid #E8E8E8;
  border-width: 1px 1px 1px 6px;
  margin: -1em 0 1em 0;
}

.post table {
  margin: -1em 0 1em 0;
  padding: .5em 1em;
  background: #F6F6F6 repeat 0 0;
}

.post pre, .post code, .post tt {
  font-family: 'droid sans mono', 'lucida console', monospace;
  line-height: 1.5;
}

.post h3 {
  font-size: 1.5em;
  line-height: 1;
  margin-bottom: .5em;
  padding-bottom: .5em;
}

.post h4 {
  font-size: 1.2em;
  line-height: 1.25;
  margin-bottom: 1.25em;
}

.post p tt,
.post p code,
.post ul code,
.post ol code {
  background: #eee;
  padding: 0 0.2em;
}



#sidebar h2 {
  font-size: 18px;
  padding: 5px 0 10px 0;
}

#sidebar h3 {
  font-size: 1.5em;
  line-height: 1;
  border-bottom: 1px solid #CCC;
  margin-bottom: .5em;
  padding-bottom: .5em;
}


table { width: 100%; border-collapse: collapse; border-spacing: 0; }
table caption { text-align: center; }
table th { font-weight: bold; }
table th, table td {
  padding: 0.3em;
  vertical-align: top;
  border-top: 1px solid #ddd;
}

table>thead:first-child>tr:first-child>td,
table>thead:first-child>tr:first-child>th {
  border-top: 0;
}

.post table>tbody>tr:nth-of-type(odd) {
  background-color: #f9f9f9;
}

div.summary {
  border-top: 3px solid #EEE;
  border-bottom: 3px solid #EEE;
  width: 580px;
  color: #666;
  margin-top: 2em;
  margin-bottom: 1em;
  padding-top: 1em;
}

div.summary ul {
  margin: 0 1.5em 1em 0;
}

span.ref {
  font-size: small;
  color: #888;
}

span.ref a {
  color: #666;
}
div.notice {
  border: 1px solid #E8E8E8; background-color: #FBFBDD; padding: .5em 1em;
}

#bottom_navi {
  font-size: larger;
  margin: 8px;
}

#sidebar {
  display: none;
}

@media (min-width: 43.75em) {
}

@media (min-width: 62em) {
  #wrapper {
    width: 960px;
  }

  #container {
    width: 72%;
    float: left;
  }

  #sidebar {
    display: block;
    width: 24%;
    float: left;
  }
}
